@@ -121,16 +121,18 @@ func ListenAndServe(ctx context.Context, addr string) error {
 	r.HandleFunc("/api/current_gps_position", positionHandler).Methods("GET")
 	r.HandleFunc("/api/qsy", qsyHandler).Methods("POST")
 	r.HandleFunc("/api/rmslist", rmslistHandler).Methods("GET")
+
+	r.PathPrefix("/dist/").Handler(distHandler())
 	r.HandleFunc("/ws", wsHandler)
 	r.HandleFunc("/ui", uiHandler()).Methods("GET")
 	r.HandleFunc("/", rootHandler).Methods("GET")
 
-	http.Handle("/", r)
-	http.Handle("/dist/", distHandler())
-
 	websocketHub = NewWSHub()
 
-	srv := http.Server{Addr: addr}
+	srv := http.Server{
+		Addr:    addr,
+		Handler: r,
+	}
 	errs := make(chan error, 1)
 	go func() {
 		errs <- srv.ListenAndServe()
@@ -282,8 +284,10 @@ func postOutboundMessageHandler(w http.ResponseWriter, r *http.Request) {
 	cookie, err := r.Cookie("forminstance")
 	if err == nil {
 		formData := formsMgr.GetPostedFormData(cookie.Value)
-		name := formsMgr.GetXMLAttachmentNameForForm(formData.TargetForm, formData.IsReply)
-		msg.AddFile(fbb.NewFile(name, []byte(formData.MsgXML)))
+		if xml := formData.MsgXML; xml != "" {
+			name := formsMgr.GetXMLAttachmentNameForForm(formData.TargetForm, formData.IsReply)
+			msg.AddFile(fbb.NewFile(name, []byte(formData.MsgXML)))
+		}
 	}
 
 	// Other fields
@@ -359,7 +363,7 @@ func attachFile(f *multipart.FileHeader, msg *fbb.Message) error {
 		return HTTPError{err, http.StatusInternalServerError}
 	}
 
-	if isImageMediaType(f.Filename, f.Header.Get("Content-Type")) {
+	if isConvertableImageMediaType(f.Filename, f.Header.Get("Content-Type")) {
 		log.Printf("Auto converting '%s' [%s]...", f.Filename, f.Header.Get("Content-Type"))
 
 		if converted, err := convertImage(p); err != nil {
