@@ -85,9 +85,11 @@ func printInteractiveUsage() {
 
 	methods := []string{
 		MethodArdop,
-		MethodAX25,
+		MethodAX25, MethodAX25AGWPE, MethodAX25Linux, MethodAX25SerialTNC,
+		MethodPactor,
 		MethodTelnet,
-		MethodSerialTNC,
+		MethodVaraHF,
+		MethodVaraFM,
 	}
 	fmt.Println("Methods:", strings.Join(methods, ", "))
 
@@ -134,8 +136,8 @@ func PrintHeard() {
 		}
 	}
 
-	fmt.Println("ax25:")
-	if heard, err := ax25.Heard(config.AX25.Port); err != nil {
+	fmt.Println("ax25+linux:")
+	if heard, err := ax25.Heard(config.AX25Linux.Port); err != nil {
 		fmt.Printf("  (%s)\n", err)
 	} else if len(heard) == 0 {
 		fmt.Println("  (none)")
