@@ -631,17 +631,18 @@ func (m *Manager) buildFormFromTxt(txtPath string) (Form, error) {
 		l := scanner.Text()
 		switch {
 		case strings.HasPrefix(l, "Form:"):
-			trimmed := strings.TrimSpace(strings.TrimPrefix(l, "Form:"))
-			fileNames := strings.Split(trimmed, ",")
-			if len(fileNames) >= 2 {
-				initial := strings.TrimSpace(fileNames[0])
-				viewer := strings.TrimSpace(fileNames[1])
-				form.InitialURI = path.Join(baseURI, initial)
-				form.ViewerURI = path.Join(baseURI, viewer)
-			} else {
-				view := strings.TrimSpace(fileNames[0])
-				form.InitialURI = path.Join(baseURI, view)
-				form.ViewerURI = path.Join(baseURI, view)
+			// Form: <composer>,<viewer>
+			files := strings.Split(strings.TrimPrefix(l, "Form:"), ",")
+			// Extend to absolute paths and add missing html extension
+			for i := range files {
+				files[i] = path.Join(baseURI, strings.TrimSpace(files[i]))
+				if ext := path.Ext(files[i]); ext == "" {
+					files[i] += ".html"
+				}
+			}
+			form.InitialURI = files[0]
+			if len(files) > 1 {
+				form.ViewerURI = files[1]
 			}
 		case strings.HasPrefix(l, "ReplyTemplate:"):
 			form.ReplyTxtFileURI = path.Join(baseURI, strings.TrimSpace(strings.TrimPrefix(l, "ReplyTemplate:")))
@@ -813,16 +814,7 @@ func (m *Manager) fillFormTemplate(absPathTemplate string, formDestURL string, p
 		log.Printf("Warning: unsupported string encoding in template %s, expected utf-8", absPathTemplate)
 	}
 
-	var (
-		now            = time.Now()
-		nowDateTime    = now.Format("2006-01-02 15:04:05")
-		nowDateTimeUTC = now.UTC().Format("2006-01-02 15:04:05Z")
-		nowDate        = now.Format("2006-01-02")
-		nowTime        = now.Format("15:04:05")
-		nowDateUTC     = now.UTC().Format("2006-01-02Z")
-		nowTimeUTC     = now.UTC().Format("15:04:05Z")
-		udtg           = strings.ToUpper(now.UTC().Format("021504Z Jan 2006"))
-	)
+	now := time.Now()
 	validPos := "NO"
 	nowPos, err := m.gpsPos()
 	if err != nil {
@@ -842,13 +834,13 @@ func (m *Manager) fillFormTemplate(absPathTemplate string, formDestURL string, p
 		l = strings.ReplaceAll(l, "{MsgSender}", m.config.MyCall)
 		l = strings.ReplaceAll(l, "{Callsign}", m.config.MyCall)
 		l = strings.ReplaceAll(l, "{ProgramVersion}", "Pat "+m.config.AppVersion)
-		l = strings.ReplaceAll(l, "{DateTime}", nowDateTime)
-		l = strings.ReplaceAll(l, "{UDateTime}", nowDateTimeUTC)
-		l = strings.ReplaceAll(l, "{Date}", nowDate)
-		l = strings.ReplaceAll(l, "{UDate}", nowDateUTC)
-		l = strings.ReplaceAll(l, "{UDTG}", udtg)
-		l = strings.ReplaceAll(l, "{Time}", nowTime)
-		l = strings.ReplaceAll(l, "{UTime}", nowTimeUTC)
+		l = strings.ReplaceAll(l, "{DateTime}", formatDateTime(now))
+		l = strings.ReplaceAll(l, "{UDateTime}", formatDateTimeUTC(now))
+		l = strings.ReplaceAll(l, "{Date}", formatDate(now))
+		l = strings.ReplaceAll(l, "{UDate}", formatDateUTC(now))
+		l = strings.ReplaceAll(l, "{UDTG}", formatUDTG(now))
+		l = strings.ReplaceAll(l, "{Time}", formatTime(now))
+		l = strings.ReplaceAll(l, "{UTime}", formatTimeUTC(now))
 		l = strings.ReplaceAll(l, "{GPS}", gpsFmt(degreeMinute, nowPos))
 		l = strings.ReplaceAll(l, "{GPS_DECIMAL}", gpsFmt(decimal, nowPos))
 		l = strings.ReplaceAll(l, "{GPS_SIGNED_DECIMAL}", gpsFmt(signedDecimal, nowPos))
@@ -949,7 +941,10 @@ func (b formMessageBuilder) build() (MessageForm, error) {
 	if err != nil {
 		return MessageForm{}, err
 	}
-	msgForm.AttachmentXML = fmt.Sprintf(`%s<RMS_Express_Form>
+
+	// Add XML if a viewer is defined for this form
+	if b.Template.ViewerURI != "" {
+		msgForm.AttachmentXML = fmt.Sprintf(`%s<RMS_Express_Form>
   <form_parameters>
     <xml_file_version>%s</xml_file_version>
     <rms_express_version>%s</rms_express_version>
@@ -964,16 +959,18 @@ func (b formMessageBuilder) build() (MessageForm, error) {
   </variables>
 </RMS_Express_Form>
 `,
-		xml.Header,
-		"1.0",
-		b.FormsMgr.config.AppVersion,
-		time.Now().UTC().Format("20060102150405"),
-		b.FormsMgr.config.MyCall,
-		b.FormsMgr.config.Locator,
-		viewer,
-		replier,
-		formVarsAsXML)
-	msgForm.AttachmentName = b.FormsMgr.GetXMLAttachmentNameForForm(b.Template, false)
+			xml.Header,
+			"1.0",
+			b.FormsMgr.config.AppVersion,
+			time.Now().UTC().Format("20060102150405"),
+			b.FormsMgr.config.MyCall,
+			b.FormsMgr.config.Locator,
+			viewer,
+			replier,
+			formVarsAsXML)
+		msgForm.AttachmentName = b.FormsMgr.GetXMLAttachmentNameForForm(b.Template, false)
+	}
+
 	msgForm.To = strings.TrimSpace(msgForm.To)
 	msgForm.Cc = strings.TrimSpace(msgForm.Cc)
 	msgForm.Subject = strings.TrimSpace(msgForm.Subject)
