@@ -8,6 +8,7 @@
 package main
 
 import (
+	"context"
 	"fmt"
 	"strings"
 
@@ -25,7 +26,10 @@ func init() {
 	commands = append(commands[:8], append([]Command{cmd}, commands[8:]...)...)
 }
 
-func riglistHandle(args []string) {
+func riglistHandle(ctx context.Context, args []string) {
+	if args[0] == "" {
+		fmt.Println("Missing argument")
+	}
 	term := strings.ToLower(args[0])
 
 	fmt.Print("id\ttransceiver\n")
