@@ -238,6 +238,12 @@ function pollFormData() {
 function writeFormDataToComposer(data) {
   if (data.target_form) {
     $('#msg_body').val(data.msg_body);
+    if (data.msg_to) {
+      $('#msg_to').tokenfield('setTokens', data.msg_to.split(/[ ;,]/).filter(Boolean));
+    }
+    if (data.msg_cc) {
+      $('#msg_cc').tokenfield('setTokens', data.msg_cc.split(/[ ;,]/).filter(Boolean));
+    }
     if (data.msg_subject) {
       // in case of composing a form-based reply we keep the 'Re: ...' subject line
       $('#msg_subject').val(data.msg_subject);
@@ -323,6 +329,7 @@ function initFormSelect(data) {
     );
     $('#updateFormsVersion').html(data.version);
     $('#formsRootFolderName').text(data.path);
+    $('#formFolderRoot').html('');
     appendFormFolder('formFolderRoot', data);
   } else {
     $('#formsRootFolderName').text('missing form templates');
@@ -348,6 +355,8 @@ function updateForms() {
           break;
         case 'update':
           $('#updateFormsResponse').text('Updated forms to ' + response.newestVersion);
+          // Update views to reflect new state
+          initForms();
           break;
       }
     },
@@ -449,8 +458,10 @@ function initConnectModal() {
       case 'varahf':
         $('#modeSearchSelect').val($(e.target).val());
         break;
-      case 'serial-tnc':
       case 'ax25':
+      case 'ax25+linux':
+      case 'ax25+agwpe':
+      case 'ax25+serial-tnc':
         $('#modeSearchSelect').val('packet');
         break;
       default:
@@ -459,10 +470,15 @@ function initConnectModal() {
     $('#modeSearchSelect').selectpicker('refresh');
     updateRmslist();
   });
+  let url = localStorage.getItem('pat_connect_url');
+  if( url != null ) {
+    setConnectValues(url);
+  }
   refreshExtraInputGroups();
 
   updateConnectAliases();
   updateRmslist();
+
 }
 
 function updateRmslist(forceDownload) {
@@ -685,7 +701,7 @@ function refreshExtraInputGroups() {
       $('#freqInputDiv').show();
   }
 
-  if (transport == 'ax25' || transport == 'serial-tnc') {
+  if (transport.startsWith('ax25')) {
     $('#radioOnlyInput')[0].checked = false;
     $('#radioOnlyInputDiv').hide();
   } else {
@@ -876,8 +892,8 @@ function closeComposer(clear) {
     $('#composer_error').val('').hide();
     $('#msg_body').val('');
     $('#msg_subject').val('');
-    $('#msg_to').tokenfield('setTokens', '');
-    $('#msg_cc').tokenfield('setTokens', '');
+    $('#msg_to').tokenfield('setTokens', []);
+    $('#msg_cc').tokenfield('setTokens', []);
     $('#composer_form')[0].reset();
 
     // Attachment previews
@@ -891,17 +907,17 @@ function closeComposer(clear) {
 }
 
 function connect(evt) {
-  const url = encodeURIComponent(getConnectURL());
-
+  const url = getConnectURL();
+  localStorage.setItem('pat_connect_url', url);
   $('#connectModal').modal('hide');
 
-  $.getJSON('/api/connect?url=' + url, function (data) {
+  $.getJSON('/api/connect?url=' + encodeURIComponent(url), function (data) {
     if (data.NumReceived == 0) {
       window.setTimeout(function () {
         alert('No new messages.');
       }, 1000);
     }
-  }).error(function () {
+  }).fail(function () {
     alert('Connect failed. See console for detailed information.');
   });
 }
